@@ -1,5 +1,5 @@
 #!/usr/bin/env python
 
-from io import read, write
+from .io import read, write
 
 __all__ = ['read', 'write']
